@@ -35,6 +35,7 @@ from speechmatics.models import (
     BatchTranscriptionConfig,
     BatchSpeakerDiarizationConfig,
     RTSpeakerDiarizationConfig,
+    BatchTranslationConfig,
 )
 from speechmatics.cli_parser import (
     parse_args,
@@ -260,6 +261,12 @@ def get_transcription_config(args):  # pylint: disable=too-many-branches
             speaker_sensitivity=speaker_sensitivity
         )
 
+    if args.get("translation_target_languages") is not None:
+        translation_target_languages = args.get("translation_target_languages")
+        config["translation_config"] = BatchTranslationConfig(
+            target_languages=translation_target_languages.split(",")
+        )
+
     if args["mode"] == "rt":
         # pylint: disable=unexpected-keyword-arg
         return TranscriptionConfig(**config)
