@@ -4,6 +4,19 @@ Exceptions and errors used by the library.
 """
 
 
+# Constants to hold valid error types for Connection Close errors
+CONN_CLOSE_ERR_TYPES = [
+    "protocol_error",
+    "not_authorised",
+    "not_allowed",
+    "invalid_model",
+    "quota_exceeded",
+    "timelimit_exceeded",
+    "job_error",
+    "internal_error",
+]
+
+
 class TranscriptionError(Exception):
     """
     Indicates an error in transcription.
